Re-exports
pub use neco_decor;pub use neco_diffcore;pub use neco_editor_search;pub use neco_editor_viewport;pub use neco_filetree;pub use neco_history;pub use neco_pathrel;pub use neco_textpatch;pub use neco_textview;pub use neco_tree;pub use neco_watchnorm;pub use neco_wrap;
Structs
- Bracket
Pair - A matched pair of brackets at byte offsets.
- Editor
Buffer - Range
Change - Abstract description of one text range change.
Enums
- Indent
Style - Detected indentation style of a text buffer.
Functions
- auto_
close_ bracket - Returns the closing counterpart for an opening bracket or quote character.
- auto_
indent - Returns the leading whitespace of the line containing
offset. - find_
matching_ bracket - Finds the matching bracket for the bracket character at
offset.